# -*- coding: utf-8 -*-
"""
Django settings for rosmorport_tsts project.

Generated by 'django-admin startproject' using Django 5.0.4.

For more information on this file, see
https://docs.djangoproject.com/en/5.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/5.0/ref/settings/
"""

import socket
from pathlib import Path

# Подключаем секретные настройки в зависимости от машины.
# ATTENTION: В git-репозитории этих файлов нет.
#            Воспользуйтесь файлом _my_secret_sample.py как образцом
if socket.gethostname() == 'erjemin-home':
    # офисный комп (Windows)
    from rosmorport_tsts.my_secret_dev_home_win import *
elif socket.gethostname() in ['m1.N1', 'm1.local', ]:
    # домашний комп (MacOS)
    from rosmorport_tsts.my_secret_dev_home_mac import *
elif socket.gethostname() in ['orangepi5', 'srv05962228.ultasrv.net']:
    # продакшн (боевой) сервер
    from rosmorport_tsts.my_secret_prod import *

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/5.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = MY_SECRET_KEY

# SECURITY WARNING: don't run with debug turned on in production!
# ПРЕДУПРЕЖДЕНИЕ БЕЗОПАСНОСТИ: не работайте в режиме DEBUG в production!
DEBUG = MY_DEBUG

# Хосты на которых может работать приложение
ALLOWED_HOSTS = MY_ALLOWED_HOSTS


# Application definition  (Определение приложений)
INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',

    'rosmorport_tsts.apps.RosmorportTstsConfig',  # Приложение проекта
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'rosmorport_tsts.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [BASE_DIR / 'templates-django', ],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
    # Добавляем шаблонизатор Jinja2 (возможно его использование в будущем)
    # {
    #     'BACKEND': 'django.template.backends.jinja2.Jinja2',
    #     'DIRS': [BASE_DIR / 'templates-jinja2', ],
    #     'APP_DIRS': True,
    #     'OPTIONS': {
    #         'environment': 'roll_cms.my_jinja2_addon.environment',
    #         'extensions': [
    #             'roll_cms.my_jinja2_addon.DjangoNow',
    #         ],
    #         'context_processors': [
    #             'django.template.context_processors.debug',
    #             'django.template.context_processors.request',
    #             'django.contrib.auth.context_processors.auth',
    #             'django.contrib.messages.context_processors.messages',
    #         ],
    #     },
    # }
]

WSGI_APPLICATION = 'rosmorport_tsts.wsgi.application'


# Database
# https://docs.djangoproject.com/en/5.0/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': BASE_DIR / 'db.sqlite3',
    }
}


# Password validation (Валидаторы паролей)
# https://docs.djangoproject.com/en/5.0/ref/settings/#auth-password-validators
AUTH_PASSWORD_VALIDATORS = [
    {'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator', },
    {'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator', },
    {'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator', },
    {'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator', },
]


# Internationalization  (Интернационализация)
# https://docs.djangoproject.com/en/4.2/topics/i18n/
LANGUAGE_CODE = 'ru-RU'
TIME_ZONE = 'Europe/Moscow'
USE_I18N = True
USE_TZ = True
FIRST_DAY_OF_WEEK = 1                           # первый день недели: понедельник
SHORT_DATE_FORMAT = '%Y-%m-%d'
SHORT_DATETIME_FORMAT = '%Y-%m-%d %H:%M:%S'

APPEND_SLASH = False


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/5.0/howto/static-files/

STATIC_URL = 'static/'
MEDIA_URL = 'media/'
MEDIA_ROOT = MY_MEDIA_ROOT
SITEMAP_ROOT = MY_SITEMAP_ROOT
if DEBUG:
    STATICFILES_DIRS = [
        MY_STATIC_ROOT
    ]
else:
    STATIC_ROOT = MY_STATIC_ROOT
    STATICFILES_DIRS = []
TOUCH_RELOAD = MY_TOUCH_RELOAD

# Default primary key field type (Тип primary key в моделях)
# https://docs.djangoproject.com/en/5.0/ref/settings/#default-auto-field
DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'
